# Hotot: RabbitMQ Python client

**Hotot** is a thin wrapper around [Pika](https://github.com/pika/pika) and [requests](http://docs.python-requests.org/en/master/) to provide: 
* clients that handle connection, publish and receive operations on RabbitMQ without any hassle.
* functions to simplify API calls

This package is named after the *(cute)* french rabbit [Blanc de Hotot](https://en.wikipedia.org/wiki/Blanc_de_Hotot).